Crate amcl_wrapper_ml

Re-exports

pub extern crate amcl;

Modules

ECCurve
commitment
constants
curve_order_elem
Represents an element where the operations are computed mod q where q is the curve order
errors
extension_field_gt
group_elem
group_elem_g1
group_elem_g2
macros
types
types_g2
univar_poly
utils

Macros

add_curve_order_elems
add_group_elems
check_vector_size_for_equality
impl_group_elem_conversions
impl_group_elem_ops
impl_group_elem_traits
impl_group_elem_vec_conversions
impl_group_elem_vec_ops
pad_collection
Takes a collection of collections and pads them with the given element such that all collections are of same length. Returns the new length. Mutates the collections.
univar_polynomial
Creates a new univariate polynomial from given coefficients from lower to higher degree terms