Re-exports
pub extern crate amcl;
Modules
- ECCurve
- commitment
- constants
- curve_
order_ elem - Represents an element where the operations are computed mod q where q is the curve order
- errors
- extension_
field_ gt - group_
elem - group_
elem_ g1 - group_
elem_ g2 - macros
- types
- types_
g2 - univar_
poly - utils
Macros
- add_
curve_ order_ elems - add_
group_ elems - check_
vector_ size_ for_ equality - impl_
group_ elem_ conversions - impl_
group_ elem_ ops - impl_
group_ elem_ traits - impl_
group_ elem_ vec_ conversions - impl_
group_ elem_ vec_ ops - pad_
collection - Takes a collection of collections and pads them with the given element such that all collections are of same length. Returns the new length. Mutates the collections.
- univar_
polynomial - Creates a new univariate polynomial from given coefficients from lower to higher degree terms